@@ -17,14 +17,6 @@ class GetValueFromEditor(UVCError):
         self.template_args = template_args
         self.prompt = prompt
     
-class BasicOutput(object):
-    def __init__(self, return_code, stdout):
-        self.return_code = return_code
-        self.output = stdout.read()
-    
-    def __str__(self):
-        return self.output
-
 class DialectCommand(object):
     """Base class for the dialect-specific command classes.
     If you subclass this, the default behavior is to pass
@@ -44,9 +36,6 @@ class DialectCommand(object):
     def __str__(self):
         return " ".join(self.command_parts())
     
-    def process_output(self, return_code, stdout):
-        return BasicOutput(return_code, stdout)
-    
     def command_parts(self):
         return self.generic.command_parts()
     
@@ -259,46 +248,6 @@ class revert(WithTargets):
     reads_remote = False
     writes_remote = False
 
-class StatusOutput(object):
-    """Output specific to a status command."""
-    
-    MODIFIED = "M"
-    ADDED = "A"
-    REMOVED = "R"
-    CLEAN = "C"
-    MISSING = "!"
-    UNKNOWN = "?"
-    IGNORED = "I"
-    valid_values = set(['M', 'A', 'R', 'C', '!', '?', 'I'])
-    
-    def __init__(self, return_code, stdout):
-        self.return_code = return_code
-        data = []
-        line = stdout.readline()
-        while line:
-            line = line.rstrip()
-            if line and line[0] in StatusOutput.valid_values:
-                data.append(line.split(" ", 1))
-            line = stdout.readline()
-        self.data = data
-    
-    def as_list(self):
-        return self.data
-    
-    def __str__(self):
-        return "\n".join(" ".join(info) for info in self.data) + "\n"
-        
-class SimpleStringOutput(object):
-    """Output that doesn't involve a return code"""
-    
-    returncode = None
-    
-    def __init__(self, output):
-        self.output = output
-        
-    def __str__(self):
-        return self.output
-        
 class push(BaseCommand):
     """The push command"""
     
