@@ -5,8 +5,7 @@ import glob
 
 import argparse
 
-from uvc.commands import UVCError, DialectCommand, StatusOutput, BaseCommand,\
-                        SimpleStringOutput
+from uvc.commands import UVCError, DialectCommand, BaseCommand
 from uvc.exc import RepositoryAlreadyInitialized
 from uvc import util
 
@@ -44,7 +43,6 @@ class AuthSVNCommand(SVNCommand):
                 parts.insert(2, auth['username'])
                 parts.insert(3, "--password")
                 parts.insert(4, auth['password'])
-                parts.insert(5, "--no-auth-cache")
     
     def command_parts(self):
         parts = super(AuthSVNCommand, self).command_parts()
@@ -77,14 +75,15 @@ class commit(SVNCommand):
     def get_command_line(self):
         return None
         
-    def get_output(self):
+    def generate_output(self, context):
         commit_log = _commit_log_file(self.generic.working_dir)
         if not commit_log.exists():
             content = self.generic.message + "\n\n"
         else:
             content = commit_log.text() + self.generic.message + "\n\n"
         commit_log.write_text(content)
-        return SimpleStringOutput("Commit message saved. Don't forget to push to save to the remote repository!")
+        context.output.write("Commit message saved. Don't forget to push to save to the remote repository!")
+        context.output.return_code = 0
 
 class diff(SVNCommand):
     reads_remote = False
@@ -140,9 +139,11 @@ class push(AuthSVNCommand):
             return None
         return super(push, self).get_command_line()
         
-    def get_output(self):
+    def generate_output(self, context):
         # only called if the commit_log doesn't exist
-        return SimpleStringOutput("Nothing to push. Run commit first.")
+        output = context.output
+        output.write("Nothing to push. Run commit first.")
+        output.return_code = 1
     
     def command_parts(self):
         parts = []
@@ -183,9 +184,6 @@ class status(SVNCommand):
     reads_remote = False
     writes_remote = False
 
-    def process_output(self, returncode, stdout):
-        return StatusOutput(returncode, stdout)
-
 class revert(SVNCommand):
     reads_remote = False
     writes_remote = False
