@@ -6,8 +6,6 @@ from uvc import commands, hg, main, exc
 from uvc.tests.util import test_context
 from uvc.tests.mock import patch
 
-StatusOutput = commands.StatusOutput
-
 dialect = hg.HgDialect()
 
 topdir = os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "..", 
@@ -137,37 +135,6 @@ def test_remove_command_no_targets():
     assert not remove.writes_remote
     assert remove.get_command_line() == ["hg", "remove", "-f", "myfile"]
     
-def test_status_command():
-    generic_status = commands.status(context, [])
-    status = hg.status(generic_status)
-    assert not status.writes_remote
-    assert not status.reads_remote
-    
-    assert status.get_command_line() == ["hg", "status"]
-    
-    status_output = """M modified/file
-A new/file
-R removed/file
-C clean/file
-! missing/file
-? unknown/file
-I ignored/file
-"""
-    
-    output = status.process_output(0, StringIO(status_output))
-    the_list = output.as_list()
-    print the_list
-    assert the_list == [
-[StatusOutput.MODIFIED, "modified/file"],
-[StatusOutput.ADDED, "new/file"],
-[StatusOutput.REMOVED, "removed/file"],
-[StatusOutput.CLEAN, "clean/file"],
-[StatusOutput.MISSING, "missing/file"],
-[StatusOutput.UNKNOWN, "unknown/file"],
-[StatusOutput.IGNORED, "ignored/file"]
-]
-    assert str(output) == status_output
-    
 @patch("uvc.main.infer_dialect")
 def test_init_command(infer_dialect):
     infer_dialect.return_value = None
